boss.factory - heros-boss 0.3.5 documentation

Skip to content
Back to top
View this page

# boss.factory

## Classes

`Factory` |
`HEROFactory` |
`DatasourceHEROFactory` |
`PolledDatasourceHEROFactory` |

## Module Contents

class boss.factory.Factory
  classmethod _build(classname: str, arg_dict: dict, name: str, realm='heros', session_manager=None, tags: list | None = None)
  classmethod _get_init_replacement(classname: str, name: str, realm: str, session_manager, tags: list | None) → Callable
    Abstractmethod:

class boss.factory.HEROFactory

  Bases: `Factory`

  _mixin_class
  classmethod build(classname: str, arg_dict: dict, name: str, realm='heros', session_manager=None, tags: list | None = None)
  classmethod _get_init_replacement(classname: str, name: str, realm: str, session_manager, tags: list | None) → Callable

class boss.factory.DatasourceHEROFactory

  Bases: `HEROFactory`

  _mixin_class
  classmethod build(classname: str, arg_dict: dict, name: str, observables: dict = {}, realm='heros', session_manager=None, tags: list | None = None)
  classmethod _get_init_replacement(classname: str, name: str, realm: str, session_manager, tags: list | None) → Callable

class boss.factory.PolledDatasourceHEROFactory

  Bases: `Factory`

  _mixin_class
  classmethod build(classname: str, arg_dict: dict, name: str, loop: asyncio.AbstractEventLoop, interval: float, observables: dict = {}, realm='heros', session_manager=None, tags: list | None = None)
  classmethod _get_init_replacement(classname: str, name: str, realm: str, session_manager, tags: list | None) → Callable